==> haskell-refact-0.3.0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refact
version:              0.3.0.2
visibility:           public
id:                   refact-0.3.0.2-HUK9hGXEPMB7VK5VJ6hNkv
key:                  refact-0.3.0.2-HUK9hGXEPMB7VK5VJ6hNkv
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
synopsis:             Specify refactorings to perform with apply-refact
description:
    This library provides a datatype which can be interpreted by apply-refact. It exists
    as a seperate library so that applications can specify refactorings without depending on GHC.

category:             Development
abi:                  6388d5a03ebf37231fb3f4e7335f6e42
exposed:              True
exposed-modules:      Refact.Types
import-dirs:          /usr/lib/ghc-8.8.3/site-local/refact-0.3.0.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/refact-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/refact-0.3.0.2
hs-libraries:         HSrefact-0.3.0.2-HUK9hGXEPMB7VK5VJ6hNkv
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-refact/html/refact.haddock
haddock-html:         /usr/share/doc/haskell-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-refact-0.3.0.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refact
version:              0.3.0.2
visibility:           public
id:                   refact-0.3.0.2-82q97AAM73L8kjBgaUANea
key:                  refact-0.3.0.2-82q97AAM73L8kjBgaUANea
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
synopsis:             Specify refactorings to perform with apply-refact
description:
    This library provides a datatype which can be interpreted by apply-refact. It exists
    as a seperate library so that applications can specify refactorings without depending on GHC.

category:             Development
abi:                  74df71d14c088435cc666a0dbb18dce3
exposed:              True
exposed-modules:      Refact.Types
import-dirs:          /usr/lib/ghc-8.10.1/site-local/refact-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/refact-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/refact-0.3.0.2
hs-libraries:         HSrefact-0.3.0.2-82q97AAM73L8kjBgaUANea
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-refact/html/refact.haddock
haddock-html:         /usr/share/doc/haskell-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
